====================
``siquant``
====================


Release v\ |release|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

Table of Contents
=================

.. toctree::
    :maxdepth: 3

    overview
    examples
    api
